import { defineUntypedSchema } from "untyped";
const schema = defineUntypedSchema({
    bytea: {
        $default: "Buffer",
        $resolve: (value) => (typeof value === "string" && ["ByteA", "Buffer", "string"].includes(value) ? value : "Buffer"),
    },
    bit: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Bit", "string", "number"].includes(value) ? value : "string"),
    },
    bitVarying: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["BitVarying", "string", "number"].includes(value) ? value : "string"),
    },
    boolean: {
        $default: "boolean",
        $resolve: (value) => (typeof value === "string" && ["Boolean", "string", "boolean", "number"].includes(value) ? value : "boolean"),
    },
    character: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Character", "string"].includes(value) ? value : "string"),
    },
    characterVarying: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["CharacterVarying", "string"].includes(value) ? value : "string"),
    },
    name: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Name", "string"].includes(value) ? value : "string"),
    },
    text: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Text", "string"].includes(value) ? value : "string"),
    },
    date: {
        $default: "globalThis.Date",
        $resolve: (value) => typeof value === "string" && ["Date", "globalThis.Date", "luxon.DateTime", "unix", "string"].includes(value) ? value : "globalThis.Date",
    },
    dateMultiRange: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["DateMultiRange", "string"].includes(value) ? value : "string"),
    },
    dateRange: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["DateRange", "string"].includes(value) ? value : "string"),
    },
    interval: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Interval", "string"].includes(value) ? value : "string"),
    },
    time: {
        $default: "globalThis.Date",
        $resolve: (value) => typeof value === "string" && ["Time", "globalThis.Date", "luxon.DateTime", "unix", "string"].includes(value) ? value : "globalThis.Date",
    },
    timestamp: {
        $default: "globalThis.Date",
        $resolve: (value) => typeof value === "string" && ["Timestamp", "globalThis.Date", "luxon.DateTime", "unix", "string"].includes(value) ? value : "globalThis.Date",
    },
    timestampMultiRange: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["TimestampMultiRange", "string"].includes(value) ? value : "string"),
    },
    timestampRange: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["TimestampRange", "string"].includes(value) ? value : "string"),
    },
    timestamptz: {
        $default: "globalThis.Date",
        $resolve: (value) => typeof value === "string" && ["TimestampTZ", "globalThis.Date", "luxon.DateTime", "unix", "string"].includes(value) ? value : "globalThis.Date",
    },
    timestamptzMultiRange: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["TimestampTZMultiRange", "string"].includes(value) ? value : "string"),
    },
    timestamptzRange: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["TimestampTZRange", "string"].includes(value) ? value : "string"),
    },
    timetz: {
        $default: "globalThis.Date",
        $resolve: (value) => typeof value === "string" && ["TimeTZ", "globalThis.Date", "luxon.DateTime", "unix", "string"].includes(value) ? value : "globalThis.Date",
    },
    box: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Box", "string"].includes(value) ? value : "string"),
    },
    circle: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Circle", "string"].includes(value) ? value : "string"),
    },
    line: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Line", "string"].includes(value) ? value : "string"),
    },
    lineSegment: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["LineSegment", "string"].includes(value) ? value : "string"),
    },
    path: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Path", "string"].includes(value) ? value : "string"),
    },
    point: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Point", "string"].includes(value) ? value : "string"),
    },
    polygon: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Polygon", "string"].includes(value) ? value : "string"),
    },
    json: {
        $default: "value",
        $resolve: (value) => (typeof value === "string" && ["JSON", "string", "value"].includes(value) ? value : "value"),
    },
    jsonb: {
        $default: "value",
        $resolve: (value) => (typeof value === "string" && ["JSON", "string", "value"].includes(value) ? value : "value"),
    },
    money: {
        $default: "number",
        $resolve: (value) => (typeof value === "string" && ["Money", "string", "BigNumber", "number"].includes(value) ? value : "number"),
    },
    float4: {
        $default: "number",
        $resolve: (value) => (typeof value === "string" && ["Float4", "string", "BigNumber", "number"].includes(value) ? value : "number"),
    },
    float8: {
        $default: "number",
        $resolve: (value) => (typeof value === "string" && ["Float8", "string", "BigNumber", "number"].includes(value) ? value : "number"),
    },
    int2: {
        $default: "number",
        $resolve: (value) => (typeof value === "string" && ["Int2", "string", "number"].includes(value) ? value : "number"),
    },
    int4: {
        $default: "number",
        $resolve: (value) => (typeof value === "string" && ["Int4", "string", "number"].includes(value) ? value : "number"),
    },
    int4MultiRange: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Int4MultiRange", "string"].includes(value) ? value : "string"),
    },
    int4Range: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Int4Range", "string"].includes(value) ? value : "string"),
    },
    int8: {
        $default: "number",
        $resolve: (value) => (typeof value === "string" && ["Int8", "string", "BigInt", "number"].includes(value) ? value : "number"),
    },
    int8MultiRange: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Int8MultiRange", "string"].includes(value) ? value : "string"),
    },
    int8Range: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["Int8Range", "string"].includes(value) ? value : "string"),
    },
    oid: {
        $default: "number",
        $resolve: (value) => (typeof value === "string" && ["OID", "string", "number"].includes(value) ? value : "number"),
    },
    uuid: {
        $default: "string",
        $resolve: (value) => (typeof value === "string" && ["UUID", "string"].includes(value) ? value : "string"),
    },
});
export default schema;
//# sourceMappingURL=DefinerModes.js.map